## covirus

![PyPI](https://img.shields.io/pypi/v/covirus) [![Build Status](https://travis-ci.com/maricatovictor/covirus.svg?branch=master)](https://travis-ci.com/maricatovictor/covirus) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) 


### Introduction

The goal of this lib is to centralize data and models related to COVID19 outbreak. 
This lib is not restricted to any country.
